Hide global variables

* Move gBn/sConstructorMap into details
* Move gDefaultServiceManager[Lock] into details and delete them from Static.h

Test: pass
Test: boots
Bug: 36075507
Change-Id: Ief7938812efe4a9fdf1d7c09850512f19023185d
diff --git a/transport/Static.cpp b/transport/Static.cpp
index d5b335e..496c8f0 100644
--- a/transport/Static.cpp
+++ b/transport/Static.cpp
@@ -19,8 +19,12 @@
 
 #include <hidl/Static.h>
 
+#include <android/hidl/manager/1.0/IServiceManager.h>
+#include <utils/Mutex.h>
+
 namespace android {
 namespace hardware {
+namespace details {
 
 Mutex gDefaultServiceManagerLock;
 sp<android::hidl::manager::V1_0::IServiceManager> gDefaultServiceManager;
@@ -31,5 +35,6 @@
 ConcurrentMap<std::string, std::function<sp<::android::hidl::base::V1_0::IBase>(void *)>>
         gBsConstructorMap;
 
-}   // namespace hardware
-}   // namespace android
+}  // namespace details
+}  // namespace hardware
+}  // namespace android